==> webkit2gtk_2.48.7.orig.tar.xz: webkitgtk-2.48.7/Source/WebKit/Shared/Extensions/WebExtensionTabParameters.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WK_WEB_EXTENSIONS)

#include "WebExtensionTabIdentifier.h"
#include "WebExtensionWindowIdentifier.h"
#include <wtf/Forward.h>

namespace WebKit {

struct WebExtensionTabParameters {
    std::optional<WebExtensionTabIdentifier> identifier;

    std::optional<URL> url;
    std::optional<String> title;

    std::optional<WebExtensionWindowIdentifier> windowIdentifier;
    std::optional<size_t> index;
#if PLATFORM(COCOA)
    std::optional<CGSize> size;
#endif

    std::optional<WebExtensionTabIdentifier> parentTabIdentifier;

    std::optional<bool> active;
    std::optional<bool> selected;
    std::optional<bool> pinned;
    std::optional<bool> audible;
    std::optional<bool> muted;
    std::optional<bool> loading;
    std::optional<bool> privateBrowsing;
    std::optional<bool> readerModeAvailable;
    std::optional<bool> showingReaderMode;
};

} // namespace WebKit

#endif // ENABLE(WK_WEB_EXTENSIONS)

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebKit/Shared/Extensions/WebExtensionTabParameters.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WK_WEB_EXTENSIONS)

#include "WebExtensionTabIdentifier.h"
#include "WebExtensionWindowIdentifier.h"
#include <WebCore/DoubleSize.h>
#include <wtf/Forward.h>

namespace WebKit {

struct WebExtensionTabParameters {
    std::optional<WebExtensionTabIdentifier> identifier;

    std::optional<URL> url;
    std::optional<String> title;

    std::optional<WebExtensionWindowIdentifier> windowIdentifier;
    std::optional<uint64_t> index;
#if PLATFORM(COCOA)
    std::optional<WebCore::DoubleSize> size;
#endif

    std::optional<WebExtensionTabIdentifier> parentTabIdentifier;

    std::optional<bool> active;
    std::optional<bool> selected;
    std::optional<bool> pinned;
    std::optional<bool> audible;
    std::optional<bool> muted;
    std::optional<bool> loading;
    std::optional<bool> privateBrowsing;
    std::optional<bool> readerModeAvailable;
    std::optional<bool> showingReaderMode;
};

} // namespace WebKit

#endif // ENABLE(WK_WEB_EXTENSIONS)
